@@ -1936,7 +1936,7 @@ get_visibility (NemoAction *action,
             condition = conditions[j];
             if (g_strcmp0 (condition, "desktop") == 0) {
                 gchar *name = nemo_file_get_display_name (parent);
-                if (g_strcmp0 (name, "x-nemo-desktop") != 0 && !priv->show_in_blank_desktop)
+                if (g_strcmp0 (name, "x-nemo-desktop") != 0 && !(parent == NULL && priv->show_in_blank_desktop))
                     condition_type_show = FALSE;
                 g_free (name);
             } else if (g_strcmp0 (condition, "removable") == 0) {
@@ -2008,7 +2008,7 @@ nemo_action_update_display_state (NemoAction *action,
                                   GtkWindow  *window)
 {
     if (get_visibility (action, selection, parent, for_places, window)) {
-        DEBUG ("Action '%s' determined VISIBLE", gtk_action_get_name (GTK_ACTION (action)));
+        DEBUG ("Action '%s' determined VISIBLE", action->uuid);
 
         finalize_strings (action, selection, parent, window);
         gtk_action_set_visible (GTK_ACTION (action), TRUE);
@@ -2016,6 +2016,6 @@ nemo_action_update_display_state (NemoAction *action,
         return;
     }
 
-    DEBUG ("Action '%s' determined HIDDEN", gtk_action_get_name (GTK_ACTION (action)));
+    DEBUG ("Action '%s' determined HIDDEN", action->uuid);
     gtk_action_set_visible (GTK_ACTION (action), FALSE);
 }
